==> xlniuxdata-league-1.0.6-20160202.092846-26-sources.jar: com/xunlei/niux/data/league/facade/FacadeImpl.java <==
package com.xunlei.niux.data.league.facade;

import org.springframework.beans.factory.annotation.Autowired;

import com.xunlei.niux.data.league.bo.BaseSo;
import com.xunlei.niux.data.league.bo.LeagueStatSo;
import com.xunlei.niux.data.league.bo.NiuxCashBo;
import com.xunlei.niux.data.league.bo.NiuxCashGenerateRecordBo;
import com.xunlei.niux.data.league.bo.PromoterBo;
import com.xunlei.niux.data.league.bo.PromoterProfitSo;

class FacadeImpl implements IFacade {
	@Autowired
	private PromoterBo promoterBo;
	@Autowired
	private NiuxCashGenerateRecordBo niuxCashGenerateRecordBo;
	@Autowired
	private NiuxCashBo niuxCashBo;
	@Autowired
	private LeagueStatSo leagueStatSo;
	@Autowired
	private PromoterProfitSo promoterProfitSo;

	@Autowired
	private BaseSo baseSo;
	

	public BaseSo getBaseSo() {
		return baseSo;
	}

	public void setBaseSo(BaseSo baseSo) {
		this.baseSo = baseSo;
	}

	public PromoterProfitSo getPromoterProfitSo() {
		return promoterProfitSo;
	}

	public void setPromoterProfitSo(PromoterProfitSo promoterProfitSo) {
		this.promoterProfitSo = promoterProfitSo;
	}

	public LeagueStatSo getLeagueStatSo() {
		return leagueStatSo;
	}

	public void setLeagueStatSo(LeagueStatSo leagueStatSo) {
		this.leagueStatSo = leagueStatSo;
	}

	public NiuxCashBo getNiuxCashBo() {
		return niuxCashBo;
	}

	public void setNiuxCashBo(NiuxCashBo niuxCashBo) {
		this.niuxCashBo = niuxCashBo;
	}

	public NiuxCashGenerateRecordBo getNiuxCashGenerateRecordBo() {
		return niuxCashGenerateRecordBo;
	}

	public void setNiuxCashGenerateRecordBo(NiuxCashGenerateRecordBo niuxCashGenerateRecordBo) {
		this.niuxCashGenerateRecordBo = niuxCashGenerateRecordBo;
	}

	public PromoterBo getPromoterBo() {
		return promoterBo;
	}

	public void setPromoterBo(PromoterBo promoterBo) {
		this.promoterBo = promoterBo;
	}
}

==> xlniuxdata-league-1.0.27-sources.jar: com/xunlei/niux/data/league/facade/FacadeImpl.java <==
package com.xunlei.niux.data.league.facade;

import com.xunlei.niux.data.league.bo.*;
import org.springframework.beans.factory.annotation.Autowired;

class FacadeImpl implements IFacade {
	@Autowired
	private PromoterBo promoterBo;
	@Autowired
	private NiuxCashGenerateRecordBo niuxCashGenerateRecordBo;
	@Autowired
	private NiuxCashBo niuxCashBo;
	@Autowired
	private LeagueStatSo leagueStatSo;
	@Autowired
	private PromoterProfitSo promoterProfitSo;
	@Autowired
	private NiuxcashPaydetailBo niuxcashPaydetailBo;
	@Autowired
	private NiuxcashPaydetailokBo niuxcashPaydetailokBo;


	public void setNiuxcashPaydetailBo(NiuxcashPaydetailBo niuxcashPaydetailBo) {
		this.niuxcashPaydetailBo = niuxcashPaydetailBo;
	}

	@Override
	public NiuxcashPaydetailokBo getNiuxcashPaydetailokBo() {
		return niuxcashPaydetailokBo;
	}

	public void setNiuxcashPaydetailokBo(NiuxcashPaydetailokBo niuxcashPaydetailokBo) {
		this.niuxcashPaydetailokBo = niuxcashPaydetailokBo;
	}

	@Autowired
	private BaseSo baseSo;
	

	public BaseSo getBaseSo() {
		return baseSo;
	}

	@Override
	public NiuxcashPaydetailBo getNiuxcashPaydetailBo() {
		return this.niuxcashPaydetailBo = niuxcashPaydetailBo;
	}

	public void setBaseSo(BaseSo baseSo) {
		this.baseSo = baseSo;
	}

	public PromoterProfitSo getPromoterProfitSo() {
		return promoterProfitSo;
	}

	public void setPromoterProfitSo(PromoterProfitSo promoterProfitSo) {
		this.promoterProfitSo = promoterProfitSo;
	}

	public LeagueStatSo getLeagueStatSo() {
		return leagueStatSo;
	}

	public void setLeagueStatSo(LeagueStatSo leagueStatSo) {
		this.leagueStatSo = leagueStatSo;
	}

	public NiuxCashBo getNiuxCashBo() {
		return niuxCashBo;
	}

	public void setNiuxCashBo(NiuxCashBo niuxCashBo) {
		this.niuxCashBo = niuxCashBo;
	}

	public NiuxCashGenerateRecordBo getNiuxCashGenerateRecordBo() {
		return niuxCashGenerateRecordBo;
	}

	public void setNiuxCashGenerateRecordBo(NiuxCashGenerateRecordBo niuxCashGenerateRecordBo) {
		this.niuxCashGenerateRecordBo = niuxCashGenerateRecordBo;
	}

	public PromoterBo getPromoterBo() {
		return promoterBo;
	}

	public void setPromoterBo(PromoterBo promoterBo) {
		this.promoterBo = promoterBo;
	}
}
